<?php

namespace UBRIR;

class Helpers
{
    public static function Transliterate($strInput)
    {
        $replace = array("А" => "A", "а" => "a", "Б" => "B", "б" => "b", "В" => "V", "в" => "v", "Г" => "G", "г" => "g", "Д" => "D", "д" => "d",
            "Е" => "E", "е" => "e", "Ё" => "E", "ё" => "e", "Ж" => "Zh", "ж" => "zh", "З" => "Z", "з" => "z", "И" => "I", "и" => "i",
            "Й" => "I", "й" => "i", "К" => "K", "к" => "k", "Л" => "L", "л" => "l", "М" => "M", "м" => "m", "Н" => "N", "н" => "n", "О" => "O", "о" => "o",
            "П" => "P", "п" => "p", "Р" => "R", "р" => "r", "С" => "S", "с" => "s", "Т" => "T", "т" => "t", "У" => "U", "у" => "u", "Ф" => "F", "ф" => "f",
            "Х" => "Kh", "х" => "kh", "Ц" => "Tc", "ц" => "tc", "Ч" => "Ch", "ч" => "ch", "Ш" => "Sh", "ш" => "sh", "Щ" => "Shch", "щ" => "shch",
            "Ы" => "Y", "ы" => "y", "Э" => "E", "э" => "e", "Ю" => "Iu", "ю" => "iu", "Я" => "Ia", "я" => "ia", "ъ" => "", "ь" => "");

        return strtr($strInput, $replace); //iconv("UTF-8", "UTF-8//IGNORE",
    }

    public static function CheckEmail($email, $bStrict = false)
    {
        if (!$bStrict) {
            $email = trim($email);
            if (preg_match("#.*?[<\\[\\(](.*?)[>\\]\\)].*#i", $email, $arr) && strlen($arr[1]) > 0)
                $email = $arr[1];
        }

        //http://tools.ietf.org/html/rfc2821#section-4.5.3.1
        //4.5.3.1. Size limits and minimums
        if (strlen($email) > 320) {
            return false;
        }

        //http://tools.ietf.org/html/rfc2822#section-3.2.4
        //3.2.4. Atom
        static $atom = "=_0-9a-z+~'!\$&*^`|\\#%/?{}-";

        //"." can't be in the beginning or in the end of local-part
        //dot-atom-text = 1*atext *("." 1*atext)
        if (preg_match("#^[" . $atom . "]+(\\.[" . $atom . "]+)*@(([-0-9a-z_]+\\.)+)([a-z0-9-]{2,20})$#i", $email)) {
            return true;
        } else {
            return false;
        }
    }

    public static function DecodeStatus($status)
    {
        switch ($status) {
            case 'APPROVED':
                return 'Одобрен (оплата прошла успешно)';
                break;
            case 'CANCELED':
                return 'Отменен (клиент прервал выполнение операции)';
                break;
            case 'DECLINED':
                return 'Отказ в оплате';
                break;
            case 'REVERSED':
                return 'Реверсирован';
                break;
            case 'REFUNDED':
                return 'Осуществлен возврат товара';
                break;
            case 'PREAUTH-APPROVED':
                return 'Выполнена предавторизация';
                break;
            case 'EXPIRED':
                return 'Истек срок действия заказа';
                break;
            case 'ON-PAYMENT':
                return 'На оплате';
                break;
            default:
                return false;
                break;
        }
    }

    public static function DecodeType($type)
    {
        switch ($type) {
            case 'Purchase':
                return 'Покупка';
                break;
            case 'Reverse':
                return 'Реверс оплаты';
                break;
            default:
                return $type;
                break;
        }
    }

    public static function DecodeOper($oper)
    {
        switch ($oper) {
            case 'CreateOrder':
                return 'Создание заказа на покупку';
                break;
            case 'GetOrderStatus':
                return 'Получение статуса заказа';
                break;
            case 'Purchase':
                return 'Покупка';
                break;
            case 'Reverse':
                return 'Реверс оплаты';
                break;
            case 'Reconcile':
                return 'Сверка итогов';
                break;
            case 'TransactionLog':
                return 'Журнал операций';
                break;
            case 'GetOrderInformation':
                return 'Получение информации о заказе';
                break;
            default:
                return $oper;
                break;
        }
    }

    /*
        private function ConvertTime($strTime)
        {
            //date
            $str = substr($strTime, 0, 2);
            //month
            $str .= '/' . substr($strTime, 2, 2);
            //year
            $str .= '/' . substr($strTime, 4, 4);
            //hour
            $str .= ' ' . substr($strTime, 8, 2);
            //minuts
            $str .= ':' . substr($strTime, 10, 2);
            //seconds
            $str .= ':' . substr($strTime, 12, 2);
            return $str;
        }
    */

// Константы-массивы не поддерживаются в php 5.3
    /*
    const Currencies = Array(
        643 => 'RUB',
        810 => 'RUB',
        840 => 'USD'
    );
    */

    static $Currencies = Array(
        643 => 'RUB',
        810 => 'RUB',
        840 => 'USD'
    );

    public static function DecodeCurrency($currencyIntCode)
    {
        $currencies = self::$Currencies;
        $currencyIntCode = intval($currencyIntCode);

        if ($currencyIntCode > 0) {
            if (isset($currencies[$currencyIntCode])) {
                return $currencies[$currencyIntCode];
            }
        }
        return 'unknown';
    }

    public static function GetUbrrCoreDir()
    {
        $curDir = __DIR__ . '/';
        $coreDir = realpath($curDir . '../../ubrr.core/');

        return $coreDir;
    }
}